# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 63.1.2-v202405160133
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnDefinitionOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_name': 'str',
        'column_type': 'str',
        'column_uom': 'str',
        'id': 'str',
        'is_indexed': 'bool',
        'rules': 'list[ColumnRule]'
    }

    attribute_map = {
        'column_name': 'columnName',
        'column_type': 'columnType',
        'column_uom': 'columnUom',
        'id': 'id',
        'is_indexed': 'isIndexed',
        'rules': 'rules'
    }

    def __init__(self, column_name=None, column_type=None, column_uom=None, id=None, is_indexed=None, rules=None):
        """
        ColumnDefinitionOutputV1 - a model defined in Swagger
        """

        self._column_name = None
        self._column_type = None
        self._column_uom = None
        self._id = None
        self._is_indexed = None
        self._rules = None

        if column_name is not None:
          self.column_name = column_name
        if column_type is not None:
          self.column_type = column_type
        if column_uom is not None:
          self.column_uom = column_uom
        if id is not None:
          self.id = id
        if is_indexed is not None:
          self.is_indexed = is_indexed
        if rules is not None:
          self.rules = rules

    @property
    def column_name(self):
        """
        Gets the column_name of this ColumnDefinitionOutputV1.
        The column definition's name

        :return: The column_name of this ColumnDefinitionOutputV1.
        :rtype: str
        """
        return self._column_name

    @column_name.setter
    def column_name(self, column_name):
        """
        Sets the column_name of this ColumnDefinitionOutputV1.
        The column definition's name

        :param column_name: The column_name of this ColumnDefinitionOutputV1.
        :type: str
        """

        self._column_name = column_name

    @property
    def column_type(self):
        """
        Gets the column_type of this ColumnDefinitionOutputV1.
        The column definition's type

        :return: The column_type of this ColumnDefinitionOutputV1.
        :rtype: str
        """
        return self._column_type

    @column_type.setter
    def column_type(self, column_type):
        """
        Sets the column_type of this ColumnDefinitionOutputV1.
        The column definition's type

        :param column_type: The column_type of this ColumnDefinitionOutputV1.
        :type: str
        """
        allowed_values = ["UUID", "TEXT", "NUMERIC", "TIMESTAMPTZ", "BOOLEAN"]
        if column_type not in allowed_values:
            raise ValueError(
                "Invalid value for `column_type` ({0}), must be one of {1}"
                .format(column_type, allowed_values)
            )

        self._column_type = column_type

    @property
    def column_uom(self):
        """
        Gets the column_uom of this ColumnDefinitionOutputV1.
        The column definition's Unit of Measure

        :return: The column_uom of this ColumnDefinitionOutputV1.
        :rtype: str
        """
        return self._column_uom

    @column_uom.setter
    def column_uom(self, column_uom):
        """
        Sets the column_uom of this ColumnDefinitionOutputV1.
        The column definition's Unit of Measure

        :param column_uom: The column_uom of this ColumnDefinitionOutputV1.
        :type: str
        """

        self._column_uom = column_uom

    @property
    def id(self):
        """
        Gets the id of this ColumnDefinitionOutputV1.
        The column definition's ID

        :return: The id of this ColumnDefinitionOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ColumnDefinitionOutputV1.
        The column definition's ID

        :param id: The id of this ColumnDefinitionOutputV1.
        :type: str
        """

        self._id = id

    @property
    def is_indexed(self):
        """
        Gets the is_indexed of this ColumnDefinitionOutputV1.
        Whether the column is indexed

        :return: The is_indexed of this ColumnDefinitionOutputV1.
        :rtype: bool
        """
        return self._is_indexed

    @is_indexed.setter
    def is_indexed(self, is_indexed):
        """
        Sets the is_indexed of this ColumnDefinitionOutputV1.
        Whether the column is indexed

        :param is_indexed: The is_indexed of this ColumnDefinitionOutputV1.
        :type: bool
        """

        self._is_indexed = is_indexed

    @property
    def rules(self):
        """
        Gets the rules of this ColumnDefinitionOutputV1.
        The rules associated with the column definition

        :return: The rules of this ColumnDefinitionOutputV1.
        :rtype: list[ColumnRule]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """
        Sets the rules of this ColumnDefinitionOutputV1.
        The rules associated with the column definition

        :param rules: The rules of this ColumnDefinitionOutputV1.
        :type: list[ColumnRule]
        """

        self._rules = rules

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnDefinitionOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 63.1.2-v202405160133
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ItemUserAttributesInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'opened_at': 'str',
        'opened_at_instant': 'int'
    }

    attribute_map = {
        'opened_at': 'openedAt',
        'opened_at_instant': 'openedAtInstant'
    }

    def __init__(self, opened_at=None, opened_at_instant=None):
        """
        ItemUserAttributesInputV1 - a model defined in Swagger
        """

        self._opened_at = None
        self._opened_at_instant = None

        if opened_at is not None:
          self.opened_at = opened_at
        if opened_at_instant is not None:
          self.opened_at_instant = opened_at_instant

    @property
    def opened_at(self):
        """
        Gets the opened_at of this ItemUserAttributesInputV1.
        The opened date of the item. Must be an ISO-8601 timestamp. If the value is 'null' the date will be cleared

        :return: The opened_at of this ItemUserAttributesInputV1.
        :rtype: str
        """
        return self._opened_at

    @opened_at.setter
    def opened_at(self, opened_at):
        """
        Sets the opened_at of this ItemUserAttributesInputV1.
        The opened date of the item. Must be an ISO-8601 timestamp. If the value is 'null' the date will be cleared

        :param opened_at: The opened_at of this ItemUserAttributesInputV1.
        :type: str
        """

        self._opened_at = opened_at

    @property
    def opened_at_instant(self):
        """
        Gets the opened_at_instant of this ItemUserAttributesInputV1.

        :return: The opened_at_instant of this ItemUserAttributesInputV1.
        :rtype: int
        """
        return self._opened_at_instant

    @opened_at_instant.setter
    def opened_at_instant(self, opened_at_instant):
        """
        Sets the opened_at_instant of this ItemUserAttributesInputV1.

        :param opened_at_instant: The opened_at_instant of this ItemUserAttributesInputV1.
        :type: int
        """

        self._opened_at_instant = opened_at_instant

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ItemUserAttributesInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 63.1.2-v202405160133
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class EmailNotificationRecipientOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email_address': 'str',
        'identity_id': 'str',
        'name': 'str',
        'redacted': 'bool'
    }

    attribute_map = {
        'email_address': 'emailAddress',
        'identity_id': 'identityId',
        'name': 'name',
        'redacted': 'redacted'
    }

    def __init__(self, email_address=None, identity_id=None, name=None, redacted=None):
        """
        EmailNotificationRecipientOutputV1 - a model defined in Swagger
        """

        self._email_address = None
        self._identity_id = None
        self._name = None
        self._redacted = None

        if email_address is not None:
          self.email_address = email_address
        if identity_id is not None:
          self.identity_id = identity_id
        if name is not None:
          self.name = name
        if redacted is not None:
          self.redacted = redacted

    @property
    def email_address(self):
        """
        Gets the email_address of this EmailNotificationRecipientOutputV1.

        :return: The email_address of this EmailNotificationRecipientOutputV1.
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """
        Sets the email_address of this EmailNotificationRecipientOutputV1.

        :param email_address: The email_address of this EmailNotificationRecipientOutputV1.
        :type: str
        """

        self._email_address = email_address

    @property
    def identity_id(self):
        """
        Gets the identity_id of this EmailNotificationRecipientOutputV1.

        :return: The identity_id of this EmailNotificationRecipientOutputV1.
        :rtype: str
        """
        return self._identity_id

    @identity_id.setter
    def identity_id(self, identity_id):
        """
        Sets the identity_id of this EmailNotificationRecipientOutputV1.

        :param identity_id: The identity_id of this EmailNotificationRecipientOutputV1.
        :type: str
        """

        self._identity_id = identity_id

    @property
    def name(self):
        """
        Gets the name of this EmailNotificationRecipientOutputV1.

        :return: The name of this EmailNotificationRecipientOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EmailNotificationRecipientOutputV1.

        :param name: The name of this EmailNotificationRecipientOutputV1.
        :type: str
        """

        self._name = name

    @property
    def redacted(self):
        """
        Gets the redacted of this EmailNotificationRecipientOutputV1.

        :return: The redacted of this EmailNotificationRecipientOutputV1.
        :rtype: bool
        """
        return self._redacted

    @redacted.setter
    def redacted(self, redacted):
        """
        Sets the redacted of this EmailNotificationRecipientOutputV1.

        :param redacted: The redacted of this EmailNotificationRecipientOutputV1.
        :type: bool
        """

        self._redacted = redacted

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, EmailNotificationRecipientOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
